﻿######################################################################################################################################################################
# Description: This script is used to delete PowerPivot Gallery Views from existing PowerPivot Galleries in SharePoint 2016.
#              It will delete any libraries named Theater, Carousel, or Gallery, so care needs to be taken while using the script!
#              You will need to modify the SharePoint site URL and manually gather the list ID of the list you want to modify and enter it into the appropriate line.
#              The rest of the script will do the work.
#              This script will prompt you before it actually deletes the views and it will set the lists default view to "All Documents" prior to the delete.
#
# Author: Rick Andring (MSFT PowerPivot for SharePoint Escalation Team)
#
# DISCLAIMER:
# Copyright (c) Microsoft Corporation. All rights reserved. This
# script is made available to you without any express, implied or
# statutory warranty, not even the implied warranty of
# merchantability or fitness for a particular purpose, or the
# warranty of title or non-infringement. The entire risk of the
# use or the results from the use of this script remains with you.
######################################################################################################################################################################

#Get SharePoint bits
Add-PSSnapin microsoft.sharepoint.powershell

#Copy your SharePoint site URL and paste it into the line below.
$site = get-spweb https://www.contoso.com

#Prints a list of lists in the web - copy the ID of the list you want to modify...
$site.lists | select title, id

#Paste the ID of the list into the next line....
$pplist = $site.lists | ? {$_.id -eq '00000000-0000-0000-0000-000000000000'}

#List relevant properties of list views (all views for the selected list).
#This is for purpose of reference and review.
$pplist.views | select Title, DefaultView, Hidden, URL, ID

#Script is Auto after this point
#capture the list views we want in variables
$modThe = $pplist.Views | ?{$_.URL -match '/Forms/Theater.aspx'}
$modCar = $pplist.Views | ?{$_.URL -match '/Forms/Carousel.aspx'}
$modGal = $pplist.Views | ?{$_.URL -match '/Forms/Gallery.aspx'}
$modAll = $pplist.Views | ?{$_.URL -match '/Forms/AllItems.aspx'}

#Prompt to proceed, no will exit script, yes will delete Gallery, Carousel and Theatre views from list and make AllItems.aspx default.
$title = "PowerPivot Gallery View Deletion"
$message = "Clicking YES will delete Gallery, Theater, and Carousel views for " + "$($site.url)/$($pplist.title)" + "/. Are you sure you wish to proceed?"
$yes = New-Object System.Management.Automation.Host.ChoiceDescription "&Yes", `
    "Deletes the PowerPivot views from the list"
$no = New-Object System.Management.Automation.Host.ChoiceDescription "&No", `
    "Cancels the delete operation"

$options = [System.Management.Automation.Host.ChoiceDescription[]]($yes, $no)

$result = $host.ui.PromptForChoice($title, $message, $options, 0) 
switch ($result) {
        0 {Write-Host -foregroundcolor green "You selected YES - DELETING GALLERY VIEWS"
            if ($modAll.DefaultView -ne $true) {
                $modAll.DefaultView=$true
                $modAll.update()
                Write-Host -ForegroundColor Green "Setting All Documents to default view it is not already."
                Write-Host -foregroundcolor Green "$($site.url)/$($modAll.Url) is now the default view!"}
            else {Write-Host -ForegroundColor Green "$($site.url)/$($modAll.Url) is already the default view!"}

            Write-Host ""
            $pplist.views.delete($modCar.ID)
            $pplist.update()
            Write-Host -foregroundcolor red "Carousel View Deleted"
            $pplist.views.delete($modGal.ID)
            $pplist.update()
            Write-Host -foregroundcolor red "Gallery View Deleted"
            $pplist.views.delete($modThe.ID)
            $pplist.update()
            Write-Host -foregroundcolor red "Theatre View Deleted"
            $site.update()
            $site.dispose()
            Write-Host -foregroundcolor green "Gallery Views are now deleted for $($site.url)/$($modAll.Url)"}
        1 {Write-Host -ForegroundColor red "You selected NO - Exiting Delete Process"}}
 