﻿######################################################################################################################################################################
# Description: This script is used to hide PowerPivot Gallery Views from existing PowerPivot Galleries in SharePoint 2016.
#              It will hide any libraries named Theater, Carousel, or Gallery, so care needs to be taken while using the script!
#              You will need to modify the SharePoint site URL and manually gather the list ID of the list you want to modify and enter it into the appropriate line.
#              The rest of the script will do the work.
#              The script will set the target library's default view to "All Documents" prior to hiding the Gallery views.
#
# Author: Rick Andring (MSFT PowerPivot for SharePoint Escalation Team)
#
# DISCLAIMER:
# Copyright (c) Microsoft Corporation. All rights reserved. This
# script is made available to you without any express, implied or
# statutory warranty, not even the implied warranty of
# merchantability or fitness for a particular purpose, or the
# warranty of title or non-infringement. The entire risk of the
# use or the results from the use of this script remains with you.
######################################################################################################################################################################

#Get SharePoint bits
Add-PSSnapin microsoft.sharepoint.powershell

#Copy your SharePoint site URL and paste it into the line below.
$site = get-spweb https://www.contoso.com

#Prints a list of lists in the web - copy the ID of the list you want to modify...
$site.lists | select title, id

#Paste the ID of the list into the next line....
$pplist = $site.lists | ? {$_.id -eq '00000000-0000-0000-0000-000000000000'}

#List relevant properties of list views (all views for the selected list).
#This is for purpose of reference and review.
$pplist.views | select Title, DefaultView, Hidden, URL, ID

#Script is Auto after this point
#capture the list views we want in variables
$modThe = $pplist.Views | ?{$_.URL -match '/Forms/Theater.aspx'}
$modCar = $pplist.Views | ?{$_.URL -match '/Forms/Carousel.aspx'}
$modGal = $pplist.Views | ?{$_.URL -match '/Forms/Gallery.aspx'}
$modAll = $pplist.Views | ?{$_.URL -match '/Forms/AllItems.aspx'}

#conditional modifications of the values.
#Makes AllItems.aspx the default view if it is not already.
#Hides Carosel, Gallery and Theatre view.
if ($modAll.DefaultView -ne $true) {
        $modAll.DefaultView=$true
        $modAll.update()
        Write-Host -foregroundcolor Red "$($site.url)/$($modAll.Url) is now the default view!"}
  else {Write-Host -ForegroundColor Red "$($site.url)/$($modAll.Url) is already the default view!"}

if ($modThe.Hidden -ne $true) {
        $modThe.Hidden=$true
        $modThe.update()
        Write-Host -foregroundcolor Green "$($site.url)/$($modThe.Url) is now hidden!"}
  else {Write-Host -ForegroundColor Green "$($site.url)/$($modThe.Url) is already hidden!"}

if ($modCar.Hidden -ne $true) {
        $modCar.Hidden=$true
        $modCar.update()
        Write-Host -foregroundcolor Green "$($site.url)/$($modCar.Url) is now hidden!"}
  else {Write-Host -ForegroundColor Green "$($site.url)/$($modCar.Url) is already hidden!"}

if ($modGal.Hidden -ne $true) {
        $modGal.Hidden=$true
        $modGal.update()
        Write-Host -foregroundcolor Green "$($site.url)/$($modGal.Url) is now hidden!"}
  else {Write-Host -ForegroundColor Green "$($site.url)/$($modGal.Url) is already hidden!"}